QueryBuilder

Struct QueryBuilder 

pub struct QueryBuilder<'a, C: QueryClient> { /* private fields */ }
Builder for constructing and executing queries.

Implementations

Source

impl<'a, C: QueryClient> QueryBuilder<'a, C>

pub fn by_correlation_id(self, id: impl Into<String>) -> Self

Query by correlation ID instead of root.

pub fn edition(self, edition: impl Into<String>) -> Self

Query events from a specific edition (diverged timeline).

pub fn range(self, lower: u32) -> Self

Query a range of sequences (inclusive lower bound).

pub fn range_to(self, lower: u32, upper: u32) -> Self

Query a range of sequences with upper bound (inclusive).

pub fn as_of_sequence(self, seq: u32) -> Self

Query state as of a specific sequence number.

pub fn as_of_time(self, rfc3339: &str) -> Result<Self>

Query state as of a specific timestamp (RFC3339 format).

pub fn build(self) -> Query

Build the Query without executing.

pub async fn get_events(self) -> Result<EventBook>

Execute the query and return the EventBook.

pub async fn get_pages(self) -> Result<Vec<EventPage>>

Execute the query and return just the event pages.