QueryClient

Struct QueryClient 

pub struct QueryClient { /* private fields */ }
Default event query client using tonic gRPC.

Implementations

Source

impl QueryClient

pub async fn connect(endpoint: &str) -> Result<Self>

Connect to an event query service at the given endpoint.

Supports both TCP (host:port) and Unix Domain Sockets (file paths).

pub async fn from_env(env_var: &str, default: &str) -> Result<Self>

Connect using an endpoint from environment variable with fallback.

pub fn from_channel(channel: Channel) -> Self

Create a client from an existing channel.

pub async fn get_events(&self, query: Query) -> Result<EventBook>

Query events for an aggregate.