pub struct CommandRequest {
pub command: Option<CommandBook>,
pub sync_mode: i32,
pub cascade_error_mode: i32,
}Expand description
Request wrapper for command operations. Adds execution metadata (sync_mode, cascade_error_mode) to CommandBook.
Fields
command: Option<CommandBook>sync_mode: i32cascade_error_mode: i32How to handle saga/PM errors in CASCADE mode
Implementations
Sourceimpl CommandRequest
impl CommandRequest
Sourcepub fn sync_mode(&self) -> SyncMode
pub fn sync_mode(&self) -> SyncMode
Returns the enum value of sync_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sync_mode(&mut self, value: SyncMode)
pub fn set_sync_mode(&mut self, value: SyncMode)
Sets sync_mode to the provided enum value.
Sourcepub fn cascade_error_mode(&self) -> CascadeErrorMode
pub fn cascade_error_mode(&self) -> CascadeErrorMode
Returns the enum value of cascade_error_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_cascade_error_mode(&mut self, value: CascadeErrorMode)
pub fn set_cascade_error_mode(&mut self, value: CascadeErrorMode)
Sets cascade_error_mode to the provided enum value.