pub struct QueryClient { /* private fields */ }Expand description
Default event query client using tonic gRPC.
Implementations
Sourceimpl QueryClient
impl QueryClient
Sourcepub async fn connect(endpoint: &str) -> Result<Self>
pub async fn connect(endpoint: &str) -> Result<Self>
Connect to an event query service at the given endpoint.
Supports both TCP (host:port) and Unix Domain Sockets (file paths).
Sourcepub async fn from_env(env_var: &str, default: &str) -> Result<Self>
pub async fn from_env(env_var: &str, default: &str) -> Result<Self>
Connect using an endpoint from environment variable with fallback.
Sourcepub fn from_channel(channel: Channel) -> Self
pub fn from_channel(channel: Channel) -> Self
Create a client from an existing channel.
Sourcepub async fn get_events(&self, query: Query) -> Result<EventBook>
pub async fn get_events(&self, query: Query) -> Result<EventBook>
Query events for an aggregate.